@@ -5,6 +5,7 @@ from __future__ import annotations
 
 from datetime import datetime
 from enum import Enum
+from enum import unique
 from typing import Any
 from typing import Literal
 from typing import Optional
@@ -90,28 +91,40 @@ BeatmapsetRequestStatus = Literal[
     "never_ranked",
 ]
 
+BEATMAP_RANK_STATUS_NAMES = {
+    -2: "graveyard",
+    -1: "wip",
+    0: "pending",
+    1: "ranked",
+    2: "approved",
+    3: "qualified",
+    4: "loved",
+}
 
+
+@unique
 class BeatmapRankStatus(Enum):
-    GRAVEYARD = (-2, "graveyard")
-    WIP = (-1, "wip")
-    PENDING = (0, "pending")
-    RANKED = (1, "ranked")
-    APPROVED = (2, "approved")
-    QUALIFIED = (3, "qualified")
-    LOVED = (4, "loved")
+    GRAVEYARD = -2
+    WIP = -1
+    PENDING = 0
+    RANKED = 1
+    APPROVED = 2
+    QUALIFIED = 3
+    LOVED = 4
 
-    def __init__(self, id: int, name_api: str) -> None:
-        self.id: int = id
-        self.name_api: str = name_api
+    @property
+    def id(self) -> int:
+        return self.value
 
-    def __int__(self) -> int:
-        return self.id
+    @property
+    def name_api(self) -> str:
+        return BEATMAP_RANK_STATUS_NAMES[self.id]
 
     def __str__(self) -> str:
         return self.name_api
 
     @classmethod
-    def _missing_(cls, query: object) -> BeatmapRankStatus:
+    def _missing_(cls, query: object) -> Any:
         if isinstance(query, int):
             for status in list(BeatmapRankStatus):
                 if status.id == query:
@@ -148,21 +161,25 @@ class BeatmapCovers(BaseModel):
     slimcover_2_x: Optional[str] = Field(alias="slimcover@2x")
 
     @classmethod
-    def _from_api_v1(cls, data: Any) -> BeatmapCovers:
+    def from_beatmapset_id(cls, beatmapset_id: int) -> BeatmapCovers:
         base_url = "https://assets.ppy.sh/beatmaps/"
         return cls.parse_obj(
             {
-                "cover": f"{base_url}{data['beatmapset_id']}/covers/cover.jpg",
-                "card": f"{base_url}{data['beatmapset_id']}/covers/card.jpg",
-                "list": f"{base_url}{data['beatmapset_id']}/covers/list.jpg",
-                "slimcover": f"{base_url}{data['beatmapset_id']}/covers/slimcover.jpg",
-                "cover_2_x": f"{base_url}{data['beatmapset_id']}/covers/cover@2x.jpg",
-                "card_2_x": f"{base_url}{data['beatmapset_id']}/covers/card@2x.jpg",
-                "list_2_x": f"{base_url}{data['beatmapset_id']}/covers/list@2x.jpg",
-                "slimcover_2_x": f"{base_url}{data['beatmapset_id']}/covers/slimcover@2x.jpg",
+                "cover": f"{base_url}{beatmapset_id}/covers/cover.jpg",
+                "card": f"{base_url}{beatmapset_id}/covers/card.jpg",
+                "list": f"{base_url}{beatmapset_id}/covers/list.jpg",
+                "slimcover": f"{base_url}{beatmapset_id}/covers/slimcover.jpg",
+                "cover_2_x": f"{base_url}{beatmapset_id}/covers/cover@2x.jpg",
+                "card_2_x": f"{base_url}{beatmapset_id}/covers/card@2x.jpg",
+                "list_2_x": f"{base_url}{beatmapset_id}/covers/list@2x.jpg",
+                "slimcover_2_x": f"{base_url}{beatmapset_id}/covers/slimcover@2x.jpg",
             },
         )
 
+    @classmethod
+    def _from_api_v1(cls, data: Any) -> BeatmapCovers:
+        return cls.from_beatmapset_id(data["beatmapset_id"])
+
 
 class BeatmapHype(BaseModel):
     current: int
@@ -229,7 +246,7 @@ class Beatmap(BaseModel):
         if values.get("url") is None:
             id = values["id"]
             beatmapset_id = values["beatmapset_id"]
-            mode = Gamemode(values["mode"])  # type: ignore
+            mode = Gamemode(values["mode"])
             values[
                 "url"
             ] = f"https://osu.ppy.sh/beatmapsets/{beatmapset_id}#{mode}/{id}"
@@ -338,7 +355,7 @@ class Beatmapset(BaseModel):
                 "favourite_count": data["favourite_count"],
                 "creator": data["creator"],
                 "play_count": data["playcount"],
-                "preview_url": f"https://b.ppy.sh/preview/{data['beatmapset_id']}.mp3",
+                "preview_url": f"//b.ppy.sh/preview/{data['beatmapset_id']}.mp3",
                 "source": data["source"],
                 "status": int(data["approved"]),
                 "title": data["title"],
