@@ -49,6 +49,7 @@ from ..models import ForumTopic
 from ..models import ForumTopicResponse
 from ..models import Gamemode
 from ..models import KudosuHistory
+from ..models import LazerScore
 from ..models import Mods
 from ..models import MultiplayerLeaderboardResponse
 from ..models import MultiplayerMatchesResponse
@@ -85,6 +86,11 @@ __all__ = ("Client",)
 ClientRequestType = Literal["GET", "POST", "DELETE", "PUT", "PATCH"]
 
 
+def to_lower_str(value: Any) -> str:
+    """Converts a value to a lowercase string."""
+    return str(value).lower()
+
+
 def get_content_type(content_type: str) -> str:
     """Returns the content type."""
     return content_type.split(";")[0]
@@ -300,7 +306,6 @@ class Client(Eventable):
                 body = await resp.read()
                 content_type = get_content_type(resp.headers.get("content-type", ""))
                 if resp.status != 200:
-                    print(self._session.headers)
                     json = orjson.loads(body)
                     raise APIException(resp.status, json.get("error", ""))
                 if content_type == "application/json":
@@ -396,7 +401,7 @@ class Client(Eventable):
         add_param(params, kwargs, key="length")
         add_param(params, kwargs, key="bpm")
         add_param(params, kwargs, key="query")
-        add_param(params, kwargs, key="is_default_sort")
+        add_param(params, kwargs, key="is_default_sort", converter=to_lower_str)
         add_param(params, kwargs, key="sort")
         add_param(params, kwargs, key="cursor_string")
         json = await self._request("GET", url)
@@ -693,7 +698,7 @@ class Client(Eventable):
         """
         url = f"{self.base_url}/api/v2/me"
         if "mode" in kwargs:
-            mode = Gamemode(kwargs.pop("mode"))  # type: ignore
+            mode = Gamemode(kwargs.pop("mode"))
             url += f"/{mode}"
         json = await self._request("GET", url)
         return User.parse_obj(json)
@@ -735,14 +740,14 @@ class Client(Eventable):
         url = f"{self.base_url}/api/v2/users/{user_query}"
         params: dict[str, Any] = {}
         if "mode" in kwargs:
-            mode = Gamemode(kwargs.pop("mode"))  # type: ignore
+            mode = Gamemode(kwargs.pop("mode"))
             url += f"/{mode}"
         add_param(
             params,
             kwargs,
             key="qtype",
             param_name="type",
-            converter=lambda x: UserQueryType(x).new_api_name,  # type: ignore
+            converter=lambda x: UserQueryType(x).new_api_name,
         )
         json = await self._request("GET", url, params=params)
         return User.parse_obj(json)
@@ -796,7 +801,7 @@ class Client(Eventable):
     @check_token
     async def __get_type_scores(
         self, user_id: int, request_type: str, **kwargs: Any
-    ) -> list[Score]:
+    ) -> list[Union[Score, LazerScore]]:
         r"""INTERNAL: Get a user's scores by type
 
         :param user_id: User ID to search by
@@ -815,12 +820,14 @@ class Client(Eventable):
                 Optional, gamemode to search for
             * *include_fails* (``bool``) --
                 Optional, whether to include failed scores, defaults to ``False``
+            * *new_format* (``bool``) --
+                Optional, whether to use the new format, defaults to ``False``
 
         :raises ValueError: If limit is not between 1 and 100
         :raises ValueError: If type is invalid
         :raises APIException: Contains status code and error message
         :return: List of requested scores
-        :rtype: list[aiosu.models.score.Score]
+        :rtype: list[aiosu.models.score.Score] or list[aiosu.models.score.LazerScore]
         """
         if not 1 <= (limit := kwargs.pop("limit", 100)) <= 100:
             raise ValueError("Invalid limit specified. Limit must be between 1 and 100")
@@ -830,15 +837,23 @@ class Client(Eventable):
             )
         url = f"{self.base_url}/api/v2/users/{user_id}/scores/{request_type}"
         params: dict[str, Any] = {
-            "include_fails": kwargs.pop("include_fails", False),
+            "include_fails": int(kwargs.pop("include_fails", False)),
             "limit": limit,
             "offset": kwargs.pop("offset", 0),
         }
-        add_param(params, kwargs, key="mode", converter=lambda x: str(Gamemode(x)))  # type: ignore
-        json = await self._request("GET", url, params=params)
+        add_param(params, kwargs, key="mode", converter=lambda x: str(Gamemode(x)))
+        headers = {}
+        new_format = kwargs.pop("new_format", False)
+        if new_format:
+            headers = {"x-api-version": "20220705"}
+        json = await self._request("GET", url, params=params, headers=headers)
+        if new_format:
+            return from_list(LazerScore.parse_obj, json)
         return from_list(Score.parse_obj, json)
 
-    async def get_user_recents(self, user_id: int, **kwargs: Any) -> list[Score]:
+    async def get_user_recents(
+        self, user_id: int, **kwargs: Any
+    ) -> list[Union[Score, LazerScore]]:
         r"""Get a user's recent scores.
 
         :param user_id: User ID to search by
@@ -855,14 +870,18 @@ class Client(Eventable):
                 Optional, whether to include failed scores, defaults to ``False``
             * *offset* (``int``) --
                 Optional, page offset to start from, defaults to 0
+            * *new_format* (``bool``) --
+                Optional, whether to use the new format, defaults to ``False``
 
         :raises APIException: Contains status code and error message
         :return: List of requested scores
-        :rtype: list[aiosu.models.score.Score]
+        :rtype: list[aiosu.models.score.Score] or list[aiosu.models.score.LazerScore]
         """
         return await self.__get_type_scores(user_id, "recent", **kwargs)
 
-    async def get_user_bests(self, user_id: int, **kwargs: Any) -> list[Score]:
+    async def get_user_bests(
+        self, user_id: int, **kwargs: Any
+    ) -> list[Union[Score, LazerScore]]:
         r"""Get a user's top scores.
 
         :param user_id: User ID to search by
@@ -875,18 +894,20 @@ class Client(Eventable):
                 Optional, gamemode to search for
             * *limit* (``int``) --
                 Optional, number of scores to get. Min: 1, Max: 100, defaults to 100
-            * *include_fails* (``bool``) --
-                Optional, whether to include failed scores, defaults to ``False``
             * *offset* (``int``) --
                 Optional, page offset to start from, defaults to 0
+            * *new_format* (``bool``) --
+                Optional, whether to use the new format, defaults to ``False``
 
         :raises APIException: Contains status code and error message
         :return: List of requested scores
-        :rtype: list[aiosu.models.score.Score]
+        :rtype: list[aiosu.models.score.Score] or list[aiosu.models.score.LazerScore]
         """
         return await self.__get_type_scores(user_id, "best", **kwargs)
 
-    async def get_user_firsts(self, user_id: int, **kwargs: Any) -> list[Score]:
+    async def get_user_firsts(
+        self, user_id: int, **kwargs: Any
+    ) -> list[Union[Score, LazerScore]]:
         r"""Get a user's first place scores.
 
         :param user_id: User ID to search by
@@ -899,14 +920,14 @@ class Client(Eventable):
                 Optional, gamemode to search for
             * *limit* (``int``) --
                 Optional, number of scores to get. Min: 1, Max: 100, defaults to 100
-            * *include_fails* (``bool``) --
-                Optional, whether to include failed scores, defaults to ``False``
             * *offset* (``int``) --
                 Optional, page offset to start from, defaults to 0
+            * *new_format* (``bool``) --
+                Optional, whether to use the new format, defaults to ``False``
 
         :raises APIException: Contains status code and error message
         :return: List of requested scores
-        :rtype: list[aiosu.models.score.Score]
+        :rtype: list[aiosu.models.score.Score] or list[aiosu.models.score.LazerScore]
         """
         return await self.__get_type_scores(user_id, "firsts", **kwargs)
 
@@ -934,7 +955,7 @@ class Client(Eventable):
         """
         url = f"{self.base_url}/api/v2/beatmaps/{beatmap_id}/scores/users/{user_id}/all"
         params: dict[str, Any] = {}
-        add_param(params, kwargs, key="mode", converter=lambda x: str(Gamemode(x)))  # type: ignore
+        add_param(params, kwargs, key="mode", converter=lambda x: str(Gamemode(x)))
         json = await self._request("GET", url, params=params)
         return from_list(Score.parse_obj, json.get("scores", []))
 
@@ -1053,7 +1074,7 @@ class Client(Eventable):
         """
         url = f"{self.base_url}/api/v2/beatmaps/{beatmap_id}/scores"
         params: dict[str, Any] = {}
-        add_param(params, kwargs, key="mode", converter=lambda x: str(Gamemode(x)))  # type: ignore
+        add_param(params, kwargs, key="mode", converter=lambda x: str(Gamemode(x)))
         add_param(params, kwargs, key="mods", converter=lambda x: str(Mods(x)))
         add_param(params, kwargs, key="type")
         json = await self._request("GET", url, params=params)
@@ -1152,10 +1173,10 @@ class Client(Eventable):
             kwargs,
             key="mode",
             param_name="ruleset_id",
-            converter=lambda x: int(Gamemode(x)),  # type: ignore
+            converter=lambda x: int(Gamemode(x)),
         )
-        add_param(data, kwargs, key="mods", converter=lambda x: str(Mods(x)))
-        json = await self._request("POST", url, data=data)
+        add_param(data, kwargs, key="mods", converter=lambda x: int(Mods(x)))
+        json = await self._request("POST", url, json=data)
         return BeatmapDifficultyAttributes.parse_obj(json.get("attributes"))
 
     @prepare_client
@@ -1307,10 +1328,10 @@ class Client(Eventable):
         add_param(params, kwargs, key="limit")
         add_param(params, kwargs, key="page")
         add_param(params, kwargs, key="message_types")
-        add_param(params, kwargs, key="only_unresolved")
+        add_param(params, kwargs, key="only_unresolved", converter=to_lower_str)
         add_param(params, kwargs, key="sort")
         add_param(params, kwargs, key="user", param_name="user_id")
-        add_param(params, kwargs, key="with_deleted")
+        add_param(params, kwargs, key="with_deleted", converter=to_lower_str)
         add_param(params, kwargs, key="cursor_string")
         json = await self._request("GET", url, params=params)
         resp = BeatmapsetDiscussionResponse.parse_obj(json)
@@ -1359,7 +1380,7 @@ class Client(Eventable):
         add_param(params, kwargs, key="sort")
         add_param(params, kwargs, key="types")
         add_param(params, kwargs, key="user", param_name="user_id")
-        add_param(params, kwargs, key="with_deleted")
+        add_param(params, kwargs, key="with_deleted", converter=to_lower_str)
         add_param(params, kwargs, key="cursor_string")
         json = await self._request("GET", url, params=params)
         resp = BeatmapsetDiscussionPostResponse.parse_obj(json)
@@ -1411,7 +1432,7 @@ class Client(Eventable):
         add_param(params, kwargs, key="score")
         add_param(params, kwargs, key="sort")
         add_param(params, kwargs, key="user", param_name="user_id")
-        add_param(params, kwargs, key="with_deleted")
+        add_param(params, kwargs, key="with_deleted", converter=to_lower_str)
         add_param(params, kwargs, key="cursor_string")
         json = await self._request("GET", url, params=params)
         resp = BeatmapsetDiscussionVoteResponse.parse_obj(json)
@@ -1623,7 +1644,7 @@ class Client(Eventable):
                 param_name="poll_options",
             )
             data["forum_topic_poll"] = forum_topic_poll
-        json = await self._request("POST", url, data=data)
+        json = await self._request("POST", url, json=data)
         return ForumCreateTopicResponse.parse_obj(json)
 
     @prepare_client
@@ -1644,7 +1665,7 @@ class Client(Eventable):
         data: dict[str, str] = {
             "body": content,
         }
-        json = await self._request("POST", url, data=data)
+        json = await self._request("POST", url, json=data)
         return ForumPost.parse_obj(json)
 
     @prepare_client
@@ -1667,7 +1688,7 @@ class Client(Eventable):
                 "topic_title": new_title,
             },
         }
-        json = await self._request("PUT", url, data=data)
+        json = await self._request("PUT", url, json=data)
         return ForumTopic.parse_obj(json)
 
     @prepare_client
@@ -1688,7 +1709,7 @@ class Client(Eventable):
         data: dict[str, str] = {
             "body": new_content,
         }
-        json = await self._request("PUT", url, data=data)
+        json = await self._request("PUT", url, json=data)
         return ForumPost.parse_obj(json)
 
     @prepare_client
@@ -1714,7 +1735,7 @@ class Client(Eventable):
         data: dict[str, Any] = {}
         add_param(data, kwargs, key="since")
         add_param(data, kwargs, key="silence_id_since", param_name="history_since")
-        json = await self._request("POST", url, data=data)
+        json = await self._request("POST", url, json=data)
         return from_list(ChatUserSilence.parse_obj, json.get("silences", []))
 
     @prepare_client
@@ -1746,14 +1767,14 @@ class Client(Eventable):
         if not 1 <= (limit := kwargs.get("limit", 50)) <= 50:
             raise ValueError("limit must be between 1 and 50")
         url = f"{self.base_url}/api/v2/chat/updates"
-        data: dict[str, Any] = {
+        params: dict[str, Any] = {
             "since": since,
             "limit:": limit,
         }
-        add_param(data, kwargs, key="channel_id")
-        add_param(data, kwargs, key="includes")
-        add_param(data, kwargs, key="silence_id_since", param_name="history_since")
-        json = await self._request("GET", url, data=data)
+        add_param(params, kwargs, key="channel_id")
+        add_param(params, kwargs, key="includes")
+        add_param(params, kwargs, key="silence_id_since", param_name="history_since")
+        json = await self._request("GET", url, params=params)
         return ChatUpdateResponse.parse_obj(json)
 
     @prepare_client
@@ -1815,12 +1836,12 @@ class Client(Eventable):
         if not 1 <= (limit := kwargs.get("limit", 50)) <= 50:
             raise ValueError("limit must be between 1 and 50")
         url = f"{self.base_url}/api/v2/chat/channels/{channel_id}/messages"
-        data: dict[str, Any] = {
+        params: dict[str, Any] = {
             "limit:": limit,
         }
-        add_param(data, kwargs, key="since")
-        add_param(data, kwargs, key="until")
-        json = await self._request("GET", url, data=data)
+        add_param(params, kwargs, key="since")
+        add_param(params, kwargs, key="until")
+        json = await self._request("GET", url, params=params)
         return from_list(ChatMessage.parse_obj, json)
 
     @prepare_client
@@ -1871,7 +1892,7 @@ class Client(Eventable):
                 "description": kwargs["channel_description"],
             }
             data["channel"] = channel
-        json = await self._request("POST", url, data=data)
+        json = await self._request("POST", url, json=data)
         return ChatChannel.parse_obj(json)
 
     @prepare_client
@@ -1948,7 +1969,7 @@ class Client(Eventable):
             "message": message,
             "is_action": is_action,
         }
-        json = await self._request("POST", url, data=data)
+        json = await self._request("POST", url, json=data)
         return ChatMessage.parse_obj(json)
 
     @prepare_client
@@ -1983,7 +2004,7 @@ class Client(Eventable):
             "is_action": is_action,
         }
         add_param(data, kwargs, key="uuid")
-        json = await self._request("POST", url, data=data)
+        json = await self._request("POST", url, json=data)
         return ChatMessageCreateResponse.parse_obj(json)
 
     @prepare_client
